@@ -1,7 +1,10 @@
 # system configuration generated and used by the sysconfig module
 build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
+ 'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
+ 'ALIGNOF_LONG': 8,
+ 'ALIGNOF_SIZE_T': 8,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
@@ -10,8 +13,8 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/opt/backend.ai/bin',
- 'BINLIBDEST': '/opt/backend.ai/lib/python3.8',
- 'BLDLIBRARY': '-L. -lpython3.8',
+ 'BINLIBDEST': '/opt/backend.ai/lib/python3.10',
+ 'BLDLIBRARY': '-L. -lpython3.10',
  'BLDSHARED': 'gcc -shared',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
@@ -30,7 +33,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
-                            '-Werror=implicit-function-declaration',
+                            '-Werror=implicit-function-declaration '
+                            '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '',
  'CONFIGURE_LDFLAGS': '',
  'CONFIGURE_LDFLAGS_NODIST': '',
@@ -39,7 +43,7 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-system-expat' '--with-system-ffi' "
                 "'--without-ensurepip' 'build_alias=x86_64-linux-musl'",
  'CONFINCLUDEDIR': '/opt/backend.ai/include',
- 'CONFINCLUDEPY': '/opt/backend.ai/include/python3.8',
+ 'CONFINCLUDEPY': '/opt/backend.ai/include/python3.10',
  'COREPYTHONPATH': '',
  'COVERAGE_INFO': '/usr/src/python/coverage.info',
  'COVERAGE_REPORT': '/usr/src/python/lcov-report',
@@ -48,11 +52,11 @@ build_time_vars = {'ABIFLAGS': '',
  'CPPFLAGS': '-I. -I./Include',
  'CXX': 'g++',
  'DESTDIRS': '/opt/backend.ai /opt/backend.ai/lib '
-             '/opt/backend.ai/lib/python3.8 '
-             '/opt/backend.ai/lib/python3.8/lib-dynload',
- 'DESTLIB': '/opt/backend.ai/lib/python3.8',
+             '/opt/backend.ai/lib/python3.10 '
+             '/opt/backend.ai/lib/python3.10/lib-dynload',
+ 'DESTLIB': '/opt/backend.ai/lib/python3.10',
  'DESTPATH': '',
- 'DESTSHARED': '/opt/backend.ai/lib/python3.8/lib-dynload',
+ 'DESTSHARED': '/opt/backend.ai/lib/python3.10/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -74,13 +78,15 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
+ 'EXPERIMENTAL_ISOLATED_SUBINTERPRETERS': 0,
+ 'EXPORTSFROM': '',
+ 'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
- 'EXT_SUFFIX': '.cpython-38-x86_64-linux-gnu.so',
+ 'EXT_SUFFIX': '.cpython-310-x86_64-linux-gnu.so',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
- 'GETTIMEOFDAY_NO_TZ': 0,
  'GITBRANCH': '',
  'GITTAG': '',
  'GITVERSION': '',
@@ -114,6 +120,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CLOCK_GETRES': 1,
  'HAVE_CLOCK_GETTIME': 1,
  'HAVE_CLOCK_SETTIME': 1,
+ 'HAVE_CLOSE_RANGE': 0,
  'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
@@ -158,6 +165,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_DLOPEN': 1,
  'HAVE_DUP2': 1,
  'HAVE_DUP3': 1,
+ 'HAVE_DYLD_SHARED_CACHE_CONTAINS_PATH': 0,
  'HAVE_DYNAMIC_LOADING': 1,
  'HAVE_ENDIAN_H': 1,
  'HAVE_EPOLL': 1,
@@ -165,6 +173,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ERF': 1,
  'HAVE_ERFC': 1,
  'HAVE_ERRNO_H': 1,
+ 'HAVE_EVENTFD': 1,
  'HAVE_EXECV': 1,
  'HAVE_EXPLICIT_BZERO': 1,
  'HAVE_EXPLICIT_MEMSET': 0,
@@ -235,7 +244,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GETSID': 1,
  'HAVE_GETSPENT': 1,
  'HAVE_GETSPNAM': 1,
- 'HAVE_GETTIMEOFDAY': 1,
  'HAVE_GETWD': 0,
  'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
@@ -267,18 +275,23 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LIBRESOLV': 0,
  'HAVE_LIBSENDFILE': 0,
  'HAVE_LIBUTIL_H': 0,
+ 'HAVE_LIBUUID': 1,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
+ 'HAVE_LINUX_AUXVEC_H': 1,
  'HAVE_LINUX_CAN_BCM_H': 1,
  'HAVE_LINUX_CAN_H': 1,
+ 'HAVE_LINUX_CAN_J1939_H': 0,
  'HAVE_LINUX_CAN_RAW_FD_FRAMES': 1,
  'HAVE_LINUX_CAN_RAW_H': 1,
+ 'HAVE_LINUX_CAN_RAW_JOIN_FILTERS': 1,
  'HAVE_LINUX_MEMFD_H': 1,
  'HAVE_LINUX_NETLINK_H': 1,
  'HAVE_LINUX_QRTR_H': 1,
  'HAVE_LINUX_RANDOM_H': 1,
  'HAVE_LINUX_TIPC_H': 1,
  'HAVE_LINUX_VM_SOCKETS_H': 1,
+ 'HAVE_LINUX_WAIT_H': 1,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
@@ -304,6 +317,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_NETPACKET_PACKET_H': 1,
  'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
+ 'HAVE_NON_UNICODE_WCHAR_T_REPRESENTATION': 0,
  'HAVE_OPENAT': 1,
  'HAVE_OPENPTY': 1,
  'HAVE_PATHCONF': 1,
@@ -330,7 +344,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PTHREAD_KILL': 1,
  'HAVE_PTHREAD_SIGMASK': 1,
  'HAVE_PTY_H': 1,
- 'HAVE_PUTENV': 1,
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 1,
  'HAVE_PWRITEV2': 0,
@@ -355,6 +368,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SCHED_SETAFFINITY': 1,
  'HAVE_SCHED_SETPARAM': 1,
  'HAVE_SCHED_SETSCHEDULER': 1,
+ 'HAVE_SEM_CLOCKWAIT': 0,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 1,
@@ -397,6 +411,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SOCKADDR_STORAGE': 1,
  'HAVE_SOCKETPAIR': 1,
  'HAVE_SPAWN_H': 1,
+ 'HAVE_SPLICE': 1,
  'HAVE_SSIZE_T': 1,
  'HAVE_STATVFS': 1,
  'HAVE_STAT_TV_NSEC': 1,
@@ -405,7 +420,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_STDINT_H': 1,
  'HAVE_STDLIB_H': 1,
  'HAVE_STD_ATOMIC': 1,
- 'HAVE_STRDUP': 1,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
@@ -427,11 +441,13 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYSCONF': 1,
  'HAVE_SYSEXITS_H': 1,
  'HAVE_SYS_AUDIOIO_H': 0,
+ 'HAVE_SYS_AUXV_H': 1,
  'HAVE_SYS_BSDTTY_H': 0,
  'HAVE_SYS_DEVPOLL_H': 0,
  'HAVE_SYS_DIR_H': 0,
  'HAVE_SYS_ENDIAN_H': 0,
  'HAVE_SYS_EPOLL_H': 1,
+ 'HAVE_SYS_EVENTFD_H': 1,
  'HAVE_SYS_EVENT_H': 0,
  'HAVE_SYS_FILE_H': 1,
  'HAVE_SYS_IOCTL_H': 1,
@@ -482,7 +498,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
  'HAVE_UNLINKAT': 1,
- 'HAVE_UNSETENV': 1,
  'HAVE_USABLE_WCHAR_T': 0,
  'HAVE_UTIL_H': 0,
  'HAVE_UTIMENSAT': 1,
@@ -493,6 +508,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UUID_GENERATE_TIME_SAFE': 1,
  'HAVE_UUID_H': 0,
  'HAVE_UUID_UUID_H': 1,
+ 'HAVE_VFORK': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
  'HAVE_WAITID': 1,
@@ -504,48 +520,49 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
- 'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'x86_64-pc-linux-musl',
  'INCLDIRSTOMAKE': '/opt/backend.ai/include /opt/backend.ai/include '
-                   '/opt/backend.ai/include/python3.8 '
-                   '/opt/backend.ai/include/python3.8',
+                   '/opt/backend.ai/include/python3.10 '
+                   '/opt/backend.ai/include/python3.10',
  'INCLUDEDIR': '/opt/backend.ai/include',
- 'INCLUDEPY': '/opt/backend.ai/include/python3.8',
+ 'INCLUDEPY': '/opt/backend.ai/include/python3.10',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 755',
- 'INSTSONAME': 'libpython3.8.so.1.0',
+ 'INSTSONAME': 'libpython3.10.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -shared',
  'LDFLAGS': '',
  'LDFLAGS_NODIST': '',
- 'LDLIBRARY': 'libpython3.8.so',
+ 'LDLIBRARY': 'libpython3.10.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'gcc -shared',
- 'LDVERSION': '3.8',
+ 'LDVERSION': '3.10',
  'LIBC': '',
- 'LIBDEST': '/opt/backend.ai/lib/python3.8',
+ 'LIBDEST': '/opt/backend.ai/lib/python3.10',
  'LIBDIR': '/opt/backend.ai/lib',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/opt/backend.ai/lib/pkgconfig',
- 'LIBPL': '/opt/backend.ai/lib/python3.8/config-3.8-x86_64-linux-gnu',
+ 'LIBPL': '/opt/backend.ai/lib/python3.10/config-3.10-x86_64-linux-gnu',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.8.a',
+ 'LIBRARY': 'libpython3.10.a',
+ 'LIBRARY_DEPS': 'libpython3.10.a libpython3.10.so libpython3.so',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-ldl  -lm',
- 'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
+ 'LIBSUBDIRS': 'asyncio \\',
  'LINKCC': 'gcc',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
  'LIPO_32BIT_FLAGS': '',
+ 'LIPO_INTEL64_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
  'LLVM_PROF_FILE': '',
  'LLVM_PROF_MERGER': 'true',
@@ -553,7 +570,7 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/opt/backend.ai/lib/python3.8',
+ 'MACHDESTLIB': '/opt/backend.ai/lib/python3.10',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
@@ -577,8 +594,8 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
             'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
             'Modules/textio.o Modules/stringio.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o Modules/hashtable.o  '
-            'Modules/symtablemodule.o  Modules/xxsubtype.o',
+            'Modules/_tracemalloc.o  Modules/symtablemodule.o  '
+            'Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': 'x86_64-linux-gnu',
  'MULTIARCH_CPPFLAGS': '-DMULTIARCH=\\"x86_64-linux-gnu\\"',
@@ -588,6 +605,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_INCLUDES': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
+ 'OPENSSL_RPATH': '',
  'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -597,12 +615,15 @@ build_time_vars = {'ABIFLAGS': '',
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ Parser/myreadline.o Parser/parsetok.o Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/tokenizer.o',
+ 'PEGEN_HEADERS': '\\',
+ 'PEGEN_OBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
  'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
+ 'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test --pgo',
+ 'PROFILE_TASK': '-m test --pgo --timeout=1200',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -615,32 +636,34 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3',
+ 'PYTHON_FOR_REGEN': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
+ 'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
                              '-fwrapv -O3 -Wall   -DTHREAD_STACK_SIZE=0x100000 '
                              '-std=c99 -Wextra -Wno-unused-result '
                              '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
-                             '-Werror=implicit-function-declaration  '
-                             '-I./Include/internal -I. -I./Include -fPIC '
-                             '-DPy_BUILD_CORE_BUILTIN',
+                             '-Werror=implicit-function-declaration '
+                             '-fvisibility=hidden  -I./Include/internal -I. '
+                             '-I./Include -fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
               '-Wall   -DTHREAD_STACK_SIZE=0x100000',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Werror=implicit-function-declaration  '
-                     '-I./Include/internal',
+                     '-Werror=implicit-function-declaration '
+                     '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
                    '-Wall   -DTHREAD_STACK_SIZE=0x100000 -std=c99 -Wextra '
                    '-Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
-                   '-Werror=implicit-function-declaration  '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '',
  'PY_CPPFLAGS': '-I. -I./Include',
+ 'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '',
  'PY_LDFLAGS_NODIST': '',
@@ -650,8 +673,9 @@ build_time_vars = {'ABIFLAGS': '',
                         '-O3 -Wall   -DTHREAD_STACK_SIZE=0x100000 -std=c99 '
                         '-Wextra -Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
-                        '-Werror=implicit-function-declaration  '
-                        '-I./Include/internal -I. -I./Include -fPIC',
+                        '-Werror=implicit-function-declaration '
+                        '-fvisibility=hidden  -I./Include/internal -I. '
+                        '-I./Include -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -663,7 +687,6 @@ build_time_vars = {'ABIFLAGS': '',
  'RUNSHARED': 'LD_LIBRARY_PATH=/usr/src/python:/opt/backend.ai/lib',
  'SCRIPTDIR': '/opt/backend.ai/lib',
  'SETPGRP_HAVE_ARG': 0,
- 'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
  'SHLIBS': '-ldl  -lm',
  'SHLIB_SUFFIX': '.so',
@@ -688,9 +711,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-38-x86_64-linux-gnu',
+ 'SOABI': 'cpython-310-x86_64-linux-gnu',
  'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
+ 'STATIC_LIBPYTHON': 1,
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -699,27 +723,33 @@ build_time_vars = {'ABIFLAGS': '',
  'SYSLIBS': '-lm',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TCLTK_INCLUDES': '',
- 'TCLTK_LIBS': '',
+ 'TCLTK_LIBS': '-ltk8.6 -ltkstub8.6 -ltcl8.6 -ltclstub8.6',
  'TESTOPTS': '',
  'TESTPATH': '',
  'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/src/python:/opt/backend.ai/lib ./python',
  'TESTPYTHONOPTS': '',
  'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/src/python:/opt/backend.ai/lib ./python '
                './Tools/scripts/run_tests.py',
+ 'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
+ 'TEST_MODULES': 'yes',
+ 'THREAD_STACK_SIZE': 0,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
+ 'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
+ 'UPDATE_FILE': './Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
- 'VERSION': '3.8',
+ 'VERSION': '3.10',
+ 'WHEEL_PKG_DIR': '',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
  'WITH_DYLD': 0,
+ 'WITH_EDITLINE': 0,
  'WITH_LIBINTL': 0,
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
